![Logo](_static/reacnetgen.svg){.reacnetgenerator-logo}

# ReacNetGenerator

An automatic reaction network generator for reactive molecular dynamics simulation

```{button-ref} ./guide/install
:color: primary
:shadow:

Get Started
```

::::{grid} 1 2 3 3
:::{grid-item-card} Trajectory
Processing of MD trajectory containing atomic coordinates or bond orders
:::
:::{grid-item-card} Filtering
Hidden Markov Model (HMM) based noise filtering
:::
:::{grid-item-card} Isomers
Isomers identifying according to SMILES
:::
:::{grid-item-card} Network
Generation of reaction network for visualization using force-directed algorithm
:::
:::{grid-item-card} HTML5
Showing an interactive web page
:::
:::{grid-item-card} Fast
Parallel computing and performance optimization
:::
::::

<div class="bilitube" data-youtube="TI21SI9YPfo" data-bvid="BV175411N7uG">Loading...</div>

## Citation and contact

```{bibliography}
---
filter: False
---
Zeng_PhysChemChemPhys_2020_v22_p683
```

jinzhe.zeng@rutgers.edu (Jinzhe Zeng), tzhu@lps.ecnu.edu.cn (Tong Zhu)

## Guide and Tutorials

You can install ReacNetGenerator with `conda`:

```sh
conda install reacnetgenerator -c conda-forge
reacnetgenerator -h
```

See [the guide](guide/index) to learn how to install and use ReacNetGenerator. We also provide [a series of tutorials](tutorial/index) to help you learn ReacNetGenerator.

## Awards

- The First Prize in 2019 (the 11th Session) Shanghai Computer Application Competition for College Students
- The First Prize in 2019 (the 12th Session) Chinese Computer Design Competition for College Students

## Acknowledge

- National Natural Science Foundation of China (Grants No. 91641116)
- National Innovation and Entrepreneurship Training Program for Undergraduate (201910269080)
- ECNU Multifunctional Platform for Innovation (No. 001)
